pub fn compile_filter(filter: &str) -> Result<VerifiedProgram, CompilationError>Expand description
Compiles a pcap filter string to BPF bytecode.
Currently the pcap filter is intended for Ethernet links.
pub fn compile_filter(filter: &str) -> Result<VerifiedProgram, CompilationError>Compiles a pcap filter string to BPF bytecode.
Currently the pcap filter is intended for Ethernet links.