pub fn parse_pcapng<'a>(
input: &'a [u8],
) -> Result<PcapNgSection<'a>, ParsingError<'a>>Expand description
Parses a pcapng file from a byte slice.
This parsing logic is not aiming to support general purpose pcap files. It expects a single section block, which begins with N interface blocks and ends with M enhanced packet blocks.