InterfaceDescriptionBlockHeader

Struct InterfaceDescriptionBlockHeader 

#[repr(C)]
pub struct InterfaceDescriptionBlockHeader { pub block_type: U32, pub block_total_length: U32, pub link_type: U16, pub reserved: U16, pub snap_len: U32, }
An Interface Description Block structure for serialization as defined in pcapng RFC Section 4.2.

Fields

block_type: U32

Block type code.

block_total_length: U32

Total length of the block.

link_type: U16

Link type.

reserved: U16

Reserved.

snap_len: U32

Maximum number of bytes from the start of a packet that gets captured.

Implementations

Source

impl InterfaceDescriptionBlockHeader

pub const SIZE: u32

The size of Self.

pub fn new(link_type: LinkType, block_total_length: u32) -> Self

Creates a new Interface Description Block header as defined in pcapng RFC Section 4.2.