pub struct ParsedEnhancedPacket<'a> {
pub interface_id: u32,
pub timestamp: SystemTime,
pub captured_length: u32,
pub original_length: u32,
pub packet_data: &'a [u8],
}Expand description
A parsed Enhanced Packet Block as defined in pcapng RFC Section 4.3.
Fields
interface_id: u32The ID of the interface the packet was captured on.
timestamp: SystemTimeThe time the packet was captured.
captured_length: u32The length of the packet data actually captured.
original_length: u32The original length of the packet off the wire.
packet_data: &'a [u8]The captured packet data.