pub struct PcapNgSection<'a> {
pub header: ParsedSectionHeader,
pub interfaces: Vec<ParsedInterfaceDescription<'a>>,
/* private fields */
}Expand description
A parsed pcapng section.
Provides an iterator to iterate over the Enhanced Packet Blocks.
Fields
header: ParsedSectionHeaderThe Section Header Block as defined in pcapng RFC Section 4.1.
interfaces: Vec<ParsedInterfaceDescription<'a>>The Interface Description Blocks as defined in pcapng RFC Section 4.2.
Implementations
Sourceimpl<'a> PcapNgSection<'a>
impl<'a> PcapNgSection<'a>
Sourcepub fn packet_blocks(&self) -> PcapNgPacketIter<'a> ⓘ
pub fn packet_blocks(&self) -> PcapNgPacketIter<'a> ⓘ
Returns an iterator over the packet blocks in the section.