#[repr(C)]pub struct SectionHeaderBlock {
pub block_type: U32,
pub block_total_length: U32,
pub byte_order_magic: U32,
pub major_version: U16,
pub minor_version: U16,
pub section_length: U64,
pub block_total_length2: U32,
}Expand description
A Section Header Block structure for serialization as defined in pcapng RFC Section 4.1.
Fields
block_type: U32Block type code.
block_total_length: U32Total length of the block.
byte_order_magic: U32Byte order magic.
major_version: U16Major version.
minor_version: U16Minor version.
section_length: U64Section length.
block_total_length2: U32Total length of the block (repeated).
Implementations
Sourceimpl SectionHeaderBlock
impl SectionHeaderBlock
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new Section Header Block with default values as defined in pcapng RFC Section 4.1.