#[repr(C)]pub struct InterfaceDescriptionBlockHeader {
pub block_type: U32,
pub block_total_length: U32,
pub link_type: U16,
pub reserved: U16,
pub snap_len: U32,
}Expand description
An Interface Description Block structure for serialization as defined in pcapng RFC Section 4.2.
Fields
block_type: U32Block type code.
block_total_length: U32Total length of the block.
link_type: U16Link type.
reserved: U16Reserved.
snap_len: U32Maximum number of bytes from the start of a packet that gets captured.
Implementations